==> stylelint_sass_coder_dev-1.0.1.tgz: package/src/rule/rule.js <==
const scssRules = {
  'scss/at-each-key-value-single-line': true,
  'scss/at-else-if-parentheses-space-before': 'never',
  'scss/at-extend-no-missing-placeholder': true,
  'scss/at-function-named-arguments': 'never',
  'scss/at-function-parentheses-space-before': 'never',
  'scss/at-function-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/at-if-no-null': true,
  'scss/at-import-no-partial-leading-underscore': true,
  'scss/at-import-partial-extension-blacklist': ['scss'],
  'scss/at-mixin-argumentless-call-parentheses': 'always',
  'scss/at-mixin-named-arguments': 'never',
  'scss/at-mixin-parentheses-space-before': 'never',
  'scss/at-mixin-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/at-rule-conditional-no-parentheses': null,
  'scss/at-rule-no-unknown': true,
  'scss/at-use-no-unnamespaced': true,
  'scss/dollar-variable-colon-space-after': 'always',
  'scss/dollar-variable-colon-space-before': 'never',
  'scss/dollar-variable-first-in-block': true,
  'scss/dollar-variable-pattern': '^[_]?[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/percent-placeholder-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/double-slash-comment-whitespace-inside': 'always',
  'scss/comment-no-empty': true,
  'scss/dimension-no-non-numeric-values': null,
  'scss/function-no-unknown': true,
  'scss/map-keys-quotes': false,
  'scss/operator-no-newline-after': null,
  'scss/operator-no-unspaced': true,
  'scss/partial-no-import': true,
  'scss/selector-no-redundant-nesting-selector': true,
  'scss/no-duplicate-dollar-variables': true,
  'scss/no-duplicate-mixins': true,
  'scss/no-global-function-names': true
};

module.exports = { scssRules };

==> stylelint_sass_coder_dev-1.0.3.tgz: package/src/rule/rule.js <==
const scssRules = {
  'scss/at-each-key-value-single-line': true,
  'scss/at-else-if-parentheses-space-before': 'never',
  'scss/at-extend-no-missing-placeholder': true,
  'scss/at-function-named-arguments': 'never',
  'scss/at-function-parentheses-space-before': 'never',
  'scss/at-function-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/at-if-no-null': true,
  'scss/at-import-no-partial-leading-underscore': true,
  'scss/at-import-partial-extension-blacklist': ['scss'],
  'scss/at-mixin-argumentless-call-parentheses': 'always',
  'scss/at-mixin-named-arguments': 'never',
  'scss/at-mixin-parentheses-space-before': 'never',
  'scss/at-mixin-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/at-rule-conditional-no-parentheses': null,
  'scss/at-rule-no-unknown': true,
  'scss/at-use-no-unnamespaced': true,
  'scss/dollar-variable-colon-space-after': 'always',
  'scss/dollar-variable-colon-space-before': 'never',
  'scss/dollar-variable-first-in-block': true,
  'scss/dollar-variable-pattern': '^[_]?[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/percent-placeholder-pattern': '^[a-z]+([a-z0-9-]+[a-z0-9]+)?$',
  'scss/double-slash-comment-whitespace-inside': 'always',
  'scss/comment-no-empty': true,
  'scss/dimension-no-non-numeric-values': null,
  'scss/function-no-unknown': true,
  'scss/map-keys-quotes': null,
  'scss/operator-no-newline-after': null,
  'scss/operator-no-unspaced': true,
  'scss/partial-no-import': true,
  'scss/selector-no-redundant-nesting-selector': true,
  'scss/no-duplicate-dollar-variables': true,
  'scss/no-duplicate-mixins': true,
  'scss/no-global-function-names': true
};

module.exports = { scssRules };
